@@ -375,6 +375,13 @@ class PlatformClient(PlatformClientBase):
                     detail = problemdetails.get("detail", detail)
                     type = problemdetails.get("type", None)
                     instance = problemdetails.get("instance", None)
+                    errors = problemdetails.get("errors", None)
+
+                    if errors:
+                        try:
+                            detail += json.dumps(errors)
+                        except:
+                            detail += str(errors) 
 
                     if detail and not message:
                         message = detail
