@@ -790,14 +790,8 @@ class MetadataClient():
         return ProjectOutput.from_body(response.Body)
 
     def update_project_access_level(self, project_id, access_level: AccessLevel) -> RowVersionOutput:
-        project = self.get_project(project_id)
-        body = {
-            "id": project_id,
-            "accessLevel": access_level.name.title(),
-            "rowVersion": project.row_version
-        }
-        response = self._client3.UpdateProjectAccessLevelV3(body)
-        return RowVersionOutput.from_body(response.Body)
+        print("Project Access Level has been deprecated since November 2022, see https://develop.mike-cloud.com/docs/API/Privileges-and-Access-Levels")
+        return RowVersionOutput(project_id, '')
     
     def get_project_members(self, project_id) -> List[ProjectMember]:
         response = self._client3.GetProjectMemberV3(project_id)
