@@ -27,11 +27,11 @@ import pandas as pd
 from dateutil import parser
 
 from dhi.platform.base.utils import sanitize_from_to
+from dhi.platform.metadata import MetadataClient
 from .base import constants
 from enum import Enum
 from typing import Generator, List, Tuple
 from dhi.platform.commonmodels import ItemDefinition, PropertyDefinition, QueryCondition
-from dhi.platform.base.exceptions import MikeCloudException
 from .generated.timeseriesgen import TimeSeriesGenClientV2
 
 class TimeseriesDatasetOutput:
@@ -275,6 +275,7 @@ class TimeSeriesClientV2(TimeSeriesGenClientV2):
 class TimeSeriesClient():
     
     def __init__(self, inspectFnc=TimeSeriesGenClientV2.DefaultInspectFnc, **kwargs):
+        self._metadata = kwargs.get("MetadataClient", MetadataClient(inspectFnc, **kwargs))
         self._ts2 = kwargs.get("TimeSeriesGenClientV2", TimeSeriesGenClientV2(inspectFnc, **kwargs))
 
     def _read_timeseries_data_from_response_data(self, data, data_fields:Tuple[DataFieldDefinition]=()):
@@ -320,7 +321,9 @@ class TimeSeriesClient():
         :rtype: TimeseriesDatasetOutput
         """
         response = self._ts2.CreateTimeseriesDatasetV2(project_id, input.body())
-        return TimeseriesDatasetOutput.from_body(response.Body)
+        output = TimeseriesDatasetOutput.from_body(response.Body)
+        self._metadata.wait_until_dataset_exists(output.id)
+        return output
 
     def create_timeseries_dataset_from_schema(self, project_id, name:str, description:str=None, timeseries_schema:Tuple[PropertyDefinition]=()):
         """
@@ -335,7 +338,9 @@ class TimeSeriesClient():
         """
         input = TimeSeriesDatasetInput(name, description, timeseries_schema)
         response = self._ts2.CreateTimeseriesDatasetV2(project_id, input.body())
-        return TimeseriesDatasetOutput.from_body(response.Body)
+        output =  TimeseriesDatasetOutput.from_body(response.Body)
+        self._metadata.wait_until_dataset_exists(output.id)
+        return output
     
     def add_timeseries_dataset_properties(self, project_id, properties:Tuple[PropertyDefinition]) -> bool:
         """
