@@ -1272,10 +1272,12 @@ class ConvertUploadInput:
             "uploadUrl": self._upload_url,
             "outputDatasetData": self._output_dataset_data.body(),
             "projectId": self._project_id,
-            "readerName": self._reader_name,
             "writerName": self._writer_name
         }
 
+        if self._reader_name is not None:
+            body["readerName"] = self._reader_name
+
         if self._transformations:
             body["transformations"] = [t.body() for t in self._transformations]
         
@@ -1349,10 +1351,13 @@ class ConvertInputBase:
         self._transformations = transformations
     
     def body(self) -> dict:
-        body = {
-            "readerName": self._reader_name,
-            "writerName": self._writer_name
-        }
+        body = {}
+        
+        if self._reader_name:
+            body["readerName"] = self._reader_name
+        
+        if self._writer_name:
+            body["writerName"] = self._writer_name
         
         if self._transformations:
             body["transformations"] = [t.body() for t in self._transformations]
@@ -1629,11 +1634,13 @@ class TransferProcessInvoker:
 
         if hasattr(transfer_pipeline, "reader"):
             reader_parameters = getattr(transfer_pipeline.reader, "parameters", ())
-            reader_name = transfer_pipeline.reader.name
+            reader_name = getattr(transfer_pipeline.reader, "name", None)
 
         if hasattr(transfer_pipeline, "writer"):
             writer_parameters = getattr(transfer_pipeline.writer, "parameters", ())
-            writer_name = transfer_pipeline.writer.name
+            writer_name = getattr(transfer_pipeline.writer, "name", None)
+            if writer_name is None:
+                raise MikeCloudException("Writer must be specified for transfer pipeline on existing dataset")
 
         dataset_info = process.dataset_info
 
